# PyMWR

PyMWR is a Python package for interacting with microwave radiometer (MWR) data. It allows users to read, plot, and analyze MWR data from various sources.



## Installation

To install PyMWR, run the following command:

```python
pip install pymwr
```

Alternatively, you can install it from source:

```
pip install git+https://github.com/imsayyed/pymwr.git
```

Or, you can install it in --user mode:

```python
git clone https://github.com/imsayyed/pymwr.git
cd pymwr
python setup.py install --user
```
## Usage

Here is an [example](./examples/examples.ipynb) of how to read and plot MWR data using PyMWR.


## Contributing

If you would like to contribute to PyMWR, please read the Contributing Guidelines.


## License

PyMWR is licensed under the MIT License.


## Authors

- [Imran Sayyed](https://github.com/imsayyed) (sayyed950@gmail.com)
- [Hamid Ali Syed](https://github.com/syedhamidali) (hamidsyed37@gmail.com)